/* 
 * cockpit node
 *
 * $Id: nCP.h 688 2006-11-27 22:34:45Z jon $
 *
 * Copyright 1999-2004 Jon Trulson under the ARTISTIC LICENSE. (See LICENSE).
 */

#ifndef _NCP_H
#define _NCP_H

void nCPInit(int istopnode);

#endif /* _NCP_H */
